from fastapi import APIRouter, Depends, HTTPException, status
from sqlalchemy.orm import Session
from core.database import get_db
from models.user import User
from schemas.user import UserSchema, UserCreate
from helpers.user_helpers import create_user

router = APIRouter()

@router.post("/signup", status_code=status.HTTP_201_CREATED, response_model=UserSchema)
async def signup(
    user: UserCreate,
    db: Session = Depends(get_db)
):
    """Create a new user with phone number"""
    new_user = create_user(db=db, user=user)
    if not new_user:
        raise HTTPException(status_code=400, detail="User could not be created")
    return new_user